// Dust washer based on the joystick surround art from Ikari Warriors.

// Logo exported from Inkscape to .dxf file using https://github.com/brad/Inkscape-OpenSCAD-DXF-Export

// The "Ikari_Dust_Washer_Numbers_55mm.dxf" file numbers and outer circle are scaled for a 55mm dust washer.

// To import the numbers and outer circle, you must place the .dxf file in the same folder as this .scad file.

// Had to slightly increase the FineThick setting from 0.4mm to 0.41mm to make the fine lines register with the slicer program. (0.4mm printer nozzle)  Check the top layer path after slicing to be sure the fine lines aren't missing.

// ------------ Define variables ------------//

// Adjustable variables
WasherOuterDiameter = 55;   // Outer diameter
WasherInnerDiameter = 16;   // Hole size
WasherThickness = 1.6;      // Washer body thickness
LogoDepth = 0.4;            // Height of raised areas
CoarseThick = 1.2;          // Coarse lines
MediumThick = 0.8;          // Medium lines
FineThick = 0.41;           // Fine lines
LineLength = 10;            // Line length
LineOffset = 13.5;          // Distance the center of the line is moved away from the center of the washer
$fn=180; // Number of fragments (polygon sides) used to render a full circle.

// Non-adjustable variables
WasherThicknessOffset = WasherThickness/2;
LogoDepthOffset = LogoDepth/2;

// ------------ Make the part ------------//

// Dust washer body
translate([0,0,-WasherThicknessOffset]) {
    difference() {
        color("Gold") cylinder(WasherThickness,d=WasherOuterDiameter,center=true); // Washer body
        cylinder(WasherThickness+2,d=WasherInnerDiameter,center=true);   // Subtract washer hole
    }
}
//

// Numbers and Outer Circle
translate([-27.5, -27.5, 0]) // X and Y center the logo
color("black") linear_extrude(height = LogoDepth, convexity = 10)
import(file = "Ikari_Dust_Washer_Numbers_55mm.dxf", layer="Numbers");

// Coarse lines
    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 0]) translate ([0,LineOffset,0]) cube ([CoarseThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 90]) translate ([0,LineOffset,0]) cube ([CoarseThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 180]) translate ([0,LineOffset,0]) cube ([CoarseThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 270]) translate ([0,LineOffset,0]) cube ([CoarseThick,LineLength,LogoDepth], center = true);

// Medium lines
    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 30]) translate ([0,LineOffset,0]) cube ([MediumThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 60]) translate ([0,LineOffset,0]) cube ([MediumThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 120]) translate ([0,LineOffset,0]) cube ([MediumThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 150]) translate ([0,LineOffset,0]) cube ([MediumThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 210]) translate ([0,LineOffset,0]) cube ([MediumThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 240]) translate ([0,LineOffset,0]) cube ([MediumThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 300]) translate ([0,LineOffset,0]) cube ([MediumThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 330]) translate ([0,LineOffset,0]) cube ([MediumThick,LineLength,LogoDepth], center = true);

// Fine lines
    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 6]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 12]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 18]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 24]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 36]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 42]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 48]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 54]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 66]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 72]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 78]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 84]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 96]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 102]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 108]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 114]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 126]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 132]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 138]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 144]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 156]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 162]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 168]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 174]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 186]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 192]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 198]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 204]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 216]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 222]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 228]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 234]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 246]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 252]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 258]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 264]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 276]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 282]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 288]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 294]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 306]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 312]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 318]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 324]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 336]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 342]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 348]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);

    translate ([0, 0, LogoDepthOffset])
    color("black") rotate ([0, 0, 354]) translate ([0,LineOffset,0]) cube ([FineThick,LineLength,LogoDepth], center = true);
